<?php

namespace Drupal\states_multiple\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class DefaultForm.
 *
 * @package Drupal\states_multiple\Form
 */
class DefaultForm extends FormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'default_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['simple'] = [
      '#type' => 'fieldset',
      '#title' => 'Simple',
    ];
    $form['simple']['dependee_simple'] = [
      '#type' => 'select',
      '#title' => $this->t('Dependee simple'),
      '#options' => [
        'a' => 'Option A',
        'b' => 'Option B',
        'c' => 'Option C',
      ],
      '#size' => 3,
    ];
    $form['simple']['dependent_simple'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Dependent simple'),
      '#maxlength' => 64,
      '#size' => 64,
      '#states' => [
        'visible' => [
          'select[name="dependee_simple"]' => ['value' => 'a'],
        ],
      ],
    ];
    
    $form['simple_default'] = [
      '#type' => 'fieldset',
      '#title' => 'Simple defaut invisible',
    ];
    $form['simple_default']['dependee_simple_default'] = [
      '#type' => 'select',
      '#title' => $this->t('Dependee simple_default'),
      '#options' => [
        'a' => 'Option A',
        'b' => 'Option B',
        'c' => 'Option C',
      ],
      '#size' => 3,
      '#default_value' => 'b',
    ];
    $form['simple_default']['dependent_simple_default'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Dependent simple_default'),
      '#maxlength' => 64,
      '#size' => 64,
      '#states' => [
        'visible' => [
          'select[name="dependee_simple_default"]' => ['value' => 'a'],
        ],
      ],
    ];

    $form['string'] = [
      '#type' => 'fieldset',
      '#title' => 'String',
    ];
    $form['string']['dependee_string'] = [
      '#type' => 'select',
      '#title' => $this->t('Dependee String'),
      '#options' => [
        'a' => 'Option A',
        'b' => 'Option B',
        'c' => 'Option C',
      ],
      '#size' => 3,
      '#multiple' => TRUE,
    ];
    $form['string']['dependent_string'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Dependent String'),
      '#maxlength' => 64,
      '#size' => 64,
      '#states' => [
        'visible' => [
          'select[name="dependee_string[]"]' => ['value' => ['a']],
        ],
      ],
    ];

    $form['number'] = [
      '#type' => 'fieldset',
      '#title' => 'Number',
    ];
    $form['number']['dependee_number'] = [
      '#type' => 'select',
      '#title' => $this->t('Dependee number'),
      '#options' => [
        0 => 'Option 0',
        1 => 'Option 1',
        2 => 'Option 2',
      ],
      '#size' => 3,
      '#multiple' => TRUE,
    ];
    $form['number']['dependent_number'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Dependent number'),
      '#maxlength' => 64,
      '#size' => 64,
      '#states' => [
        'visible' => [
          'select[name="dependee_number[]"]' => ['value' => [0]],
        ],
      ],
    ];

    $form['number_string'] = [
      '#type' => 'fieldset',
      '#title' => 'Number check with string',
    ];
    $form['number_string']['dependee_number_string'] = [
      '#type' => 'select',
      '#title' => $this->t('Dependee number_string'),
      '#options' => [
        0 => 'Option 0',
        1 => 'Option 1',
        2 => 'Option 2',
      ],
      '#size' => 3,
      '#multiple' => TRUE,
    ];
    $form['number_string']['dependent_number_string'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Dependent number_string'),
      '#maxlength' => 64,
      '#size' => 64,
      '#states' => [
        'visible' => [
          'select[name="dependee_number_string[]"]' => ['value' => '0'],
        ],
      ],
    ];

    $form['string_default_visible'] = [
      '#type' => 'fieldset',
      '#title' => 'String with default visible',
    ];
    $form['string_default_visible']['dependee_string_default_visible'] = [
      '#type' => 'select',
      '#title' => $this->t('Dependee string_default_visible'),
      '#options' => [
        'a' => 'Option A',
        'b' => 'Option B',
        'c' => 'Option C',
      ],
      '#size' => 3,
      '#multiple' => TRUE,
      '#default_value' => 'a',
    ];
    $form['string_default_visible']['dependent_string_default_visible'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Dependent string_default_visible'),
      '#maxlength' => 64,
      '#size' => 64,
      '#states' => [
        'visible' => [
          'select[name="dependee_string_default_visible[]"]' => ['value' => ['a']],
        ],
      ],
    ];

    $form['string_default_invisible'] = [
      '#type' => 'fieldset',
      '#title' => 'String with default invisible',
    ];
    $form['string_default_invisible']['dependee_string_default_invisible'] = [
      '#type' => 'select',
      '#title' => $this->t('Dependee string_default_invisible'),
      '#options' => [
        'a' => 'Option A',
        'b' => 'Option B',
        'c' => 'Option C',
      ],
      '#size' => 3,
      '#multiple' => TRUE,
      '#default_value' => 'b',
    ];
    $form['string_default_invisible']['dependent_string_default_invisible'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Dependent string_default_invisible'),
      '#maxlength' => 64,
      '#size' => 64,
      '#states' => [
        'visible' => [
          'select[name="dependee_string_default_invisible[]"]' => ['value' => ['a']],
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

  }

}
